import copy
import sys
from datetime import datetime, timedelta

import numpy as np
import pandas as pd
import peakutils as pk
import plotly.graph_objs as go
import plotly.offline as py
from netCDF4 import Dataset, date2num, num2date

units = 'seconds since 1970-01-01'


class DeepDive:
    """
    :ivar max_depth: the max depth in the dive
    :ivar min_depth: the max depth in the dive
    :ivar dive_start: the timestamp of the first point in the dive
    :ivar dive_end: the timestamp of the last point in the dive
    :ivar td_total_duration: a timedelta (in seconds since 1970-01-01)
        containing the duration of the dive
    :ivar depth_variance: the variance of the depth for the entire dive.
    :ivar average_vertical_velocity: the mean velocity of the animal over the
        entire dive with negative value indicating upward movement
    :ivar average_descent_velocity: the average velocity of any downward
        movement as positive value
    :ivar average_ascent_velocity: the average velocity of any upward movement
        as positive value
    :ivar number_of_descent_transitions: the number of times and animal moves
        descends any distance in the dive period
    :ivar number_of_ascent_transitions: the number of times and animal moves
        ascends any distance in the dive period
    :ivar total_descent_distance_traveled: the total absolute distance in
        meters in which the anaimal moves down
    :ivar total_ascent_distance_traveled: the total absolute distance in
        meters in which the anaimal moves up
    :ivar overall_change_in_depth: the difference between the minimum and
        maximum depth within the dive period
    :ivar td_time_at_depth: the duration in seconds at which the animal spends
        in the deepest part of the vertical movement (< 85% depth)
    :ivar td_time_pre_depth: the duration in seconds befor the deepest part of
        the vertical movement (< 85% depth)
    :ivar td_time_post_depth: the duration in seconds after the deepest part
        of the vertical movement (< 85% depth)
    :ivar peaks: the number of peaks found in the dive profile
    :ivar left_skew: a boolean of 1 or 0 indicating if the dive is left skewed
    :ivar right_skew: a boolean of 1 or 0 indicating if the dive is right
        skewed
    :ivar no_skew: a boolean of 1 or 0 indicating if the dive is not skewed

    """

    def __init__(self,
                 data,
                 columns={
                     'depth': 'depth',
                     'time': 'time'
                 },
                 at_depth_threshold=0.15):
        """
        :param data: the time and depth values for the dive
        :param columns: a dictionary of column mappings for the data
        :param at_depth_threshold: a value from 0 - 1 indicating distance from
            the bottom of the dive at which the animal is considered to be at
            depth
        """

        if data[columns['time']].dtypes != np.float64:
            data.time = date2num(data.time.tolist(), units=units)

        self.data = data.sort_values('time').reset_index(drop=True)
        for k, v in columns.items():
            if k != v:
                self.data[k] = self.data[v]
                self.data.drop(v, axis=1)

        self.max_depth = self.data.depth.max()
        self.min_depth = self.data.depth.min()
        self.dive_start = self.data.time.min()
        self.dive_end = self.data.time.max()
        self.td_total_duration = self.data.time.max() - self.data.time.min()
        self.depth_variance = np.std(self.data.depth)
        self.average_vertical_velocity = np.absolute(
            ((self.data.depth.diff() / self.data.time.diff()))).mean()
        self.average_descent_velocity = self.get_average_descent_velocity()
        self.average_ascent_velocity = self.get_average_ascent_velocity()

        self.number_of_descent_transitions = \
            len(self.data[(self.data.depth.diff() /
                           self.data.time.diff()) > 0])

        self.number_of_ascent_transitions = \
            len(self.data[(self.data.depth.diff() /
                           self.data.time.diff()) < 0])

        self.total_descent_distance_traveled =  \
            self.get_descent_vertical_distance()

        self.total_ascent_distance_traveled =   \
            self.get_ascent_vertical_distance()

        self.overall_change_in_depth = self.data.depth.diff().sum()
        self.td_time_at_depth = self.get_time_at_depth(at_depth_threshold)
        self.td_time_pre_depth = self.get_time_pre_depth(at_depth_threshold)
        self.td_time_post_depth = self.get_time_post_depth(at_depth_threshold)
        self.peaks = self.get_peaks()
        self.no_skew = 0
        self.right_skew = 0
        self.left_skew = 0
        self.set_skew()

    def get_peaks(self):
        """
        :return: number of peaks found within a dive
        """
        peak_thres = (1 - (self.data.depth.min() / self.data.depth.max()))
        peaks = pk.indexes(
            self.data.depth * (-1),
            thres=min([0.1, peak_thres]),
            min_dist=max((10 / self.data.time.diff().mean()), 3))
        self.peaks = len(peaks)
        return self.peaks

    def set_skew(self):
        """
        Sets the objects skew as left, right, or no skew
        """
        if self.td_time_pre_depth > self.td_time_post_depth:
            self.left_skew = 1
        elif self.td_time_post_depth > self.td_time_pre_depth:
            self.left_skew = 1
        else:
            self.no_skew = 1

    def get_time_at_depth(self, at_depth_threshold=0.15):
        """
        :param at_depth_threshold: a value from 0 - 1 indicating distance from
            the bottom of the dive at which the animal is considered to be at
            depth
        :return: the duration at depth in seconds
        """
        time = 0
        dive = self.data.copy(deep=True)
        dive['time_diff'] = dive.time.diff()
        time_data = dive[
            dive.depth > (dive.depth.max() - (
                (dive.depth.max() - dive.depth.min()) * at_depth_threshold)
            )
        ].tail(-1)
        if len(time_data) != 0:
            time = time_data.time_diff.sum()
        del dive
        return time

    def get_time_pre_depth(self, at_depth_threshold=0.15):
        """
        :param at_depth_threshold: a value from 0 - 1 indicating distance from
            the bottom of the dive at which the animal is considered to be at
            depth
        :return: the duration before depth in seconds
        """
        time = 0
        dive = self.data.copy(deep=True)
        dive['time_diff'] = dive.time.diff()
        at_depth_data = dive[
            dive.depth > (dive.depth.max() - (
                (dive.depth.max() - dive.depth.min()) * at_depth_threshold)
            )
        ].tail(-1)
        time_data = dive[dive.time < at_depth_data.time.min()]
        if len(time_data) != 0:
            time = time_data.time_diff.sum()
        del dive
        return time

    def get_time_post_depth(self, at_depth_threshold=0.15):
        """
        :param at_depth_threshold: a value from 0 - 1 indicating distance from
            the bottom of the dive at which the animal is considered to be at
            depth
        :return: the duration after depth in seconds
        """
        time = 0
        dive = self.data.copy(deep=True)
        dive['time_diff'] = dive.time.diff()
        at_depth_data = dive[
            dive.depth > (dive.depth.max() - (
                (dive.depth.max() - dive.depth.min()) * at_depth_threshold)
            )
        ].tail(-1)
        time_data = dive[dive.time > at_depth_data.time.max()]
        if len(time_data) != 0:
            time = time_data.time_diff.sum()
        del dive
        return time

    def get_descent_vertical_distance(self):
        """
        :return: the total vertical distance travelled upwards in meters
        """
        dive = self.data.copy(deep=True)
        dive['depth_diff'] = dive.depth.diff()
        distance = np.absolute(dive[(dive.depth_diff > 0)].depth_diff.sum())
        del dive
        return distance

    def get_ascent_vertical_distance(self):
        """
        :return: the total vertical distance travelled downwards in meters
        """
        dive = self.data.copy(deep=True)
        dive['depth_diff'] = dive.depth.diff()
        distance = np.absolute(dive[(dive.depth_diff < 0)].depth_diff.sum())
        del dive
        return distance

    def get_average_ascent_velocity(self):
        """
        :return: the average upwards velocity in m/s
        """
        dive = self.data.copy(deep=True)
        dive['velocity'] = dive.depth.diff() / dive.time.diff()
        velocity = np.absolute(dive[dive.velocity < 0].velocity.mean())
        del dive
        return velocity

    def get_average_descent_velocity(self):
        """
        :return: the average downwards velocity in m/s
        """
        dive = self.data.copy(deep=True)
        dive['velocity'] = dive.depth.diff() / dive.time.diff()
        velocity = np.absolute(dive[dive.velocity > 0].velocity.mean())
        del dive
        return velocity

    def to_dict(self):
        """

        :return: a dictionary of the dive profile
        """
        dive = copy.deepcopy(self.__dict__)
        del dive['data']
        return dive

    def plot(self):
        """
        :return: a plotly graph showing the phases of the dive
        """
        # Set the data to plot the segments of the dive
        dive = self.data.copy(deep=True)
        dive['time_diff'] = dive.time.diff()

        at_depth_data = dive[dive.depth > (dive.depth.max() - (
            (dive.depth.max() - dive.depth.min()) * at_depth_threshold))]
        pre_depth_data = dive[(dive.depth < (dive.depth.max() - (
            (dive.depth.max() - dive.depth.min()) * at_depth_threshold))) &
            (dive.time <= at_depth_data.time.min())]
        post_depth_data = dive[(dive.depth < (dive.depth.max() - (
            (dive.depth.max() - dive.depth.min()) * at_depth_threshold))) &
            (dive.time >= at_depth_data.time.max())]

        pre_depth_data = pre_depth_data.append(at_depth_data.head(1))
        post_depth_data = post_depth_data.append(at_depth_data.tail(1))
        post_depth_data.sort_values('time', inplace=True)

        pre_depth = go.Scatter(
            x=num2date(pre_depth_data.time.tolist(), units=units),
            y=pre_depth_data.depth,
            mode='lines+markers',
            name='Pre Depth')

        at_depth = go.Scatter(
            x=num2date(at_depth_data.time.tolist(), units=units),
            y=at_depth_data.depth,
            mode='lines+markers',
            name='At Depth')

        post_depth = go.Scatter(
            x=num2date(post_depth_data.time.tolist(), units=units),
            y=post_depth_data.depth,
            mode='lines+markers',
            name='Post Depth')

        layout = go.Layout(
            title='Dive starting at {}'.format(
                num2date(self.dive_start, units=units)),
            xaxis=dict(title='Time'),
            yaxis=dict(title='Depth in Meters', autorange='reversed'))
        plot_data = [pre_depth, post_depth, at_depth]
        fig = go.Figure(data=plot_data, layout=layout)
        return py.iplot(fig)



import math

import numpy as np
import pandas as pd
import xarray as xr
from netCDF4 import Dataset, date2num, num2date


def zlib_encoding(ds):
    """
    This is a helper function for xarray to compress all variables going to
    netCDF

    :param ds: an xarray Dataset

    :return: A dictionary indicating zlib compression for all variables
    """
    comp = dict(zlib=True)
    encoding = {var: comp for var in ds.data_vars}
    return encoding


def calculate_window_mean(window, surface_threshold, df):
    """

    :param window: an int to determine the size for a rolling median
    :param surface_threshold: the maximum depth that will be considered for the
        offset
    :param df: Pandas Dataframe of the dive data

    :return: An average offset in meters using the defined window
    """
    data = df.copy(deep=True)
    data['adjusted_depth'] = data[
        data.depth <= surface_threshold].depth.rolling(window).median()
    data.adjusted_depth = data.adjusted_depth.interpolate()
    data.adjusted_depth = data.depth - data.adjusted_depth
    avg_adjustment = (data.depth - data.adjusted_depth).mean()
    del data
    return avg_adjustment


def correct_depth_offset(data,
                         window=3600,
                         columns={
                             'depth': 'depth',
                             'time': 'time'
                         },
                         aux_file='corrected_depth_auxillary_data.nc',
                         method='max',
                         surface_threshold=4):
    """
    :param data: The dataset consisting of a time and a depth column
    :param window: time window (in seconds) to use in the calculation
    :param aux_file: A netCDF file to write all of the calculated offsets and
        window size
    :param columns: column renaming dictionary if needed
    :param method: either 'max' or 'mean' declaring the calculation method,
        default is max
    :param surface_threshold: maximum values (in meters) to use when using the
        mean the calculate

    :return: A DataFrame with a corrected depth
    """

    if method == 'mean':
        window_means = pd.DataFrame(
            np.arange(10, 1001, step=10), columns=['window_size'])
        window_means['offset_mean'] = window_means.window_size.apply(
            calculate_window_mean, args=(surface_threshold, data))
        window = window_means.iloc[(
            (window_means.offset_mean.diff() / window_means.window_size).diff(
            ) / window_means.window_size).idxmin()].window_size.astype(int)

        data['depth_offset'] = data[data.depth < animal_length].depth.rolling(
            window).median()
        data.depth_offset = data.depth_offset.interpolate().fillna(0)
        data['corrected_depth'] = data.depth - data.depth_offset
    else:
        data['offset'] = data.depth.rolling(
            int(window / data.time.diff().mean().total_seconds())).min()
        data.offset.fillna(data.offset.min(), inplace=True)
        data['corrected_depth'] = data.depth - data.offset

    data['window_size_in_seconds'] = window
    corrected_data = pd.DataFrame()
    corrected_data['time'] = data.time
    corrected_data['depth'] = data.corrected_depth

    time_units = 'seconds since 1970-01-01'
    data.time = date2num(pd.to_datetime(data.time).tolist(), units=time_units)
    xarray_data = xr.Dataset(data)
    xarray_data.variables['time'].attrs = {'units': time_units}
    xarray_data.variables['depth'].attrs = {
        'units': 'meters',
        'positive': 'down'
    }
    xarray_data.variables['corrected_depth'].attrs = {
        'units': 'meters',
        'positive': 'down'
    }
    xarray_data.to_netcdf(
        aux_file, mode='w', encoding=zlib_encoding(xarray_data))
    xarray_data.close()

    return corrected_data



import os

import colorlover as cl
import pandas as pd
import plotly.graph_objs as go
import plotly.offline as py
import xarray as xr
from netCDF4 import Dataset, num2date


def plot_from_nc(folder,
                 cluster,
                 dive_id,
                 ipython_display=True,
                 type='dive',
                 filename='index.html',
                 at_depth_threshold=0.15):
    """
    :param folder: the path to the results folder contianing the cluster
        folders
    :param cluster: the number of the cluster of the dive
    :param dive_id: the number of of the dive
    :param type: a string of either either ``dive`` or ``deepdive``
    :param ipython_display: a boolean indicating whether or not to show the
        dive in a notebook
    :param filename: the filename to save the dive to if it is not shown in a
        notebook
    :param at_depth_threshold: a value from 0 - 1 indicating distance from the
        bottom of the dive at which the animal is considered to be at depth

    :return: a plotly line chart of the dive

    """
    if type == 'deepdive':
        return plot_deepdive_from_nc(folder, cluster, dive_id, ipython_display,
                                     filename, at_depth_threshold)
    else:
        return plot_dive_from_nc(folder, cluster, dive_id, ipython_display,
                                 filename)


def plot_dive_from_nc(folder,
                      cluster,
                      dive_id,
                      ipython_display=True,
                      filename='index.html',
                      at_depth_threshold=0.15,
                      title='Clusters'):
    """
    :param folder: the path to the results folder contianing the cluster
        folders
    :param cluster: the number of the cluster of the dive
    :param dive_id: the number of of the dive
    :param ipython_display: a boolean indicating whether or not to show the
        dive in a notebook
    :param filename: the filename to save the dive to if it is not shown in a
        notebook
    :param at_depth_threshold: a value from 0 - 1 indicating distance from the
        bottom of the dive at which the animal is considered to be at depth
    :param title: string title of plot

    :return: a plotly line chart of the dive

    """
    dive_file = '%s/cluster_%d/dive_%05d.nc' % (folder, cluster, dive_id)
    rootgrp = Dataset(dive_file)
    data = pd.DataFrame()
    data['time'] = rootgrp.variables['time'][:]
    data['depth'] = rootgrp.variables['depth'][:]

    # Get and set the surface data
    surface_data = data[data.time >= (
        data.time.max() - rootgrp.td_surface_duration)]

    surface = go.Scatter(
        x=num2date(surface_data.time.tolist(), units=rootgrp.time_units),
        y=surface_data.depth,
        mode='lines',
        name='Surface')

    # Get and set the bottom data
    bottom_data = data[(data.time >= rootgrp.bottom_start) & (
        data.time <= (rootgrp.bottom_start + rootgrp.td_bottom_duration))]
    bottom = go.Scatter(
        x=num2date(bottom_data.time.tolist(), units=rootgrp.time_units),
        y=bottom_data.depth,
        mode='lines',
        name='Bottom')

    descent_data = data[data.time <= bottom_data.time.min()]
    descent = go.Scatter(
        x=num2date(descent_data.time.tolist(), units=rootgrp.time_units),
        y=descent_data.depth,
        mode='lines',
        name='Descent')

    # Get and set the ascent data
    ascent_data = data[
        (data.time >= bottom_data.time.max()) &
        (data.time <= surface_data.time.min())
    ]
    ascent = go.Scatter(
        x=num2date(ascent_data.time.tolist(), units=rootgrp.time_units),
        y=ascent_data.depth,
        mode='lines',
        name='Ascent')

    layout = go.Layout(
        title='Dive {} from Cluster {}'.format(rootgrp.dive_id,
                                               rootgrp.cluster),
        xaxis=dict(title='Time'),
        yaxis=dict(title='Depth in Meters', autorange='reversed'))
    rootgrp.close()

    plot_data = [descent, bottom, ascent, surface]
    fig = go.Figure(data=plot_data, layout=layout)

    if ipython_display:
        py.init_notebook_mode()
        return py.iplot(fig)
    else:
        return py.plot(fig, filename=filename)


def plot_deepdive_from_nc(folder,
                          cluster,
                          dive_id,
                          ipython_display=True,
                          filename='index.html',
                          at_depth_threshold=0.15):
    """
    :param folder: the path to the results folder contianing the cluster
        folders
    :param cluster: the number of the cluster of the dive
    :param dive_id: the number of of the dive
    :param ipython_display: a boolean indicating whether or not to show the
        dive in a notebook
    :param filename: the filename to save the dive to if it is not shown in a
        notebook
    :param at_depth_threshold: a value from 0 - 1 indicating distance from the
        bottom of the dive at which the animal is considered to be at depth

    :return: a plotly line chart of the dive

    """
    dive_file = '%s/cluster_%d/dive_%05d.nc' % (folder, cluster, dive_id)
    rootgrp = Dataset(dive_file)
    data = pd.DataFrame()
    data['time'] = rootgrp.variables['time'][:]
    data['depth'] = rootgrp.variables['depth'][:]
    units = rootgrp.variables['time'].units
    at_depth_data = data[data.depth > (data.depth.max() - (
        (data.depth.max() - data.depth.min()) * at_depth_threshold))]
    pre_depth_data = data[(data.depth < (data.depth.max() - (
        (data.depth.max() - data.depth.min()) * at_depth_threshold))) &
        (data.time <= at_depth_data.time.min())]
    post_depth_data = data[(data.depth < (data.depth.max() - (
        (data.depth.max() - data.depth.min()) * at_depth_threshold))) &
        (data.time >= at_depth_data.time.max())]

    pre_depth_data = pre_depth_data.append(at_depth_data.head(1))
    post_depth_data = post_depth_data.append(at_depth_data.tail(1))
    post_depth_data.sort_values('time', inplace=True)

    pre_depth = go.Scatter(
        x=num2date(pre_depth_data.time.tolist(), units=units),
        y=pre_depth_data.depth,
        mode='lines+markers',
        name='Pre Depth')

    at_depth = go.Scatter(
        x=num2date(at_depth_data.time.tolist(), units=units),
        y=at_depth_data.depth,
        mode='lines+markers',
        name='At Depth')

    post_depth = go.Scatter(
        x=num2date(post_depth_data.time.tolist(), units=units),
        y=post_depth_data.depth,
        mode='lines+markers',
        name='Post Depth')

    layout = go.Layout(
        title='Dive {} from Cluster {}'.format(rootgrp.dive_id,
                                               rootgrp.cluster),
        xaxis=dict(title='Time'),
        yaxis=dict(title='Depth in Meters', autorange='reversed'))
    rootgrp.close()
    plot_data = [pre_depth, post_depth, at_depth]
    fig = go.Figure(data=plot_data, layout=layout)
    if ipython_display:
        py.init_notebook_mode()
        return py.iplot(fig)
    else:
        return py.plot(fig, filename=filename)


def cluster_summary_plot(folder,
                         ipython_display=True,
                         filename='index.html',
                         title='Dive Cluster Summary',
                         scale={
                             'depth': False,
                             'time': False
                         }):
    """
    :param folder: the path to the results folder contianing the cluster
        folders
    :param ipython_display: a boolean indicating whether or not to show the
        dive in a notebook
    :param filename: the filename to save the dive to if it is not shown in a
        notebook
    :param title: the displaye title of the plot

    :return: a plotly graph summary of all of the dive clusters

    """

    dataset = xr.open_dataset(os.path.join(folder, 'all_profiled_dives.nc'))
    df = dataset.to_dataframe().reset_index(drop=True)
    df.sort_values('dive_start', inplace=True)
    df['dive_id'] = df.index + 1

    xaxis = 'time'
    xaxis_title = 'Time in Seconds into Dive'

    yaxis = 'depth'
    yaxis_title = 'Depth in Meters'

    dive_data = pd.DataFrame()
    for group, data in df.groupby('cluster'):
        for index, row in data.iterrows():
            dive_file = '%s/cluster_%d/dive_%05d.nc' % (folder, row.cluster,
                                                        row.dive_id)
            rootgrp = Dataset(dive_file)
            single_dive_data = pd.DataFrame()
            single_dive_data['depth'] = rootgrp.variables['depth'][:]
            single_dive_data['time'] = rootgrp.variables['time'][:]
            single_dive_data['time'] = single_dive_data['time'] - \
                single_dive_data['time'].min()
            if 'time' in scale.keys() and scale['time']:
                single_dive_data['progress_into_dive'] = round(
                    single_dive_data.time / single_dive_data.time.max() * 100,
                    0)
                xaxis = 'progress_into_dive'
                xaxis_title = 'Progress Through Dive (%)'

            if 'depth' in scale.keys() and scale['depth']:
                single_dive_data['dive_relative_depth_percentage'] = round(
                    single_dive_data.depth / single_dive_data.depth.max() *
                    100, 0)
                yaxis = 'dive_relative_depth_percentage'
                yaxis_title = 'Depth (%) Relative to the Dive'
            single_dive_data['cluster'] = rootgrp.cluster
            dive_data = dive_data.append(single_dive_data)
            rootgrp.close()

    aggregated_data = dive_data.groupby([xaxis, 'cluster']).agg(
        ['min', 'mean', 'max', 'median', 'count']).reset_index(level=[0, 1])

    plot_data = []
    colors = cl.scales[str(len(
        aggregated_data.cluster.unique()))]['qual']['Paired']

    for cluster in aggregated_data.cluster.unique():

        line_trace = go.Scatter(
            x=aggregated_data[aggregated_data.cluster == cluster][xaxis],
            y=aggregated_data[aggregated_data.cluster == cluster][yaxis][
                'min'],
            mode='lines',
            legendgroup='cluster' + str(cluster),
            name='Cluster ' + str(cluster) + " Min Depth",
            line=go.scatter.Line(color=colors[cluster], dash='dash'))
        plot_data.append(line_trace)

        fill_trace = go.Scatter(
            x=aggregated_data[aggregated_data.cluster == cluster][xaxis],
            y=aggregated_data[aggregated_data.cluster == cluster][yaxis][
                'max'],
            fill='tonexty',
            mode='lines',
            legendgroup='cluster' + str(cluster),
            fillcolor=colors[cluster].replace(')', ',0.3)').replace(
                'rgb', 'rgba'),
            name='Cluster ' + str(cluster) + ' Possible Range',
            line=go.scatter.Line(width=0, color=colors[cluster]),
        )
        plot_data.append(fill_trace)

        line_trace = go.Scatter(
            x=aggregated_data[aggregated_data.cluster == cluster][xaxis],
            y=aggregated_data[aggregated_data.cluster == cluster][yaxis][
                'mean'],
            mode='lines',
            legendgroup='cluster' + str(cluster),
            name='Cluster ' + str(cluster) + " Average Depth",
            line=go.scatter.Line(color=colors[cluster]),
        )
        plot_data.append(line_trace)

    layout = go.Layout(
        title=title,
        xaxis=dict(title=xaxis_title, range=[0, aggregated_data[xaxis].max()]),
        yaxis=dict(title=yaxis_title, autorange='reversed'))
    py.init_notebook_mode()
    fig = go.Figure(data=plot_data, layout=layout)
    if ipython_display:
        py.init_notebook_mode()
        return py.iplot(fig)
    else:
        return py.plot(fig, filename=filename)



# -*- coding: utf-8 -*-

from codecs import open

from setuptools import find_packages, setup

with open('README.md') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()

setup(
    name='divebomb',
    version='1.1.1',
    description='divebomb dive classification algorithm',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='Alex Nunes',
    include_package_data=True,
    author_email='alex.et.nunes@gmail.com',
    url='https://github.com/ocean-tracking-network/divebomb',
    download_url='https://github.com/ocean-tracking-network/divebomb',
    license='GPLv2',
    classifiers=[
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],

    packages=find_packages(exclude=('tests', 'docs'))
)
